Method: UsingYAML.path=
- Defined in:
- lib/using_yaml.rb
.path=(args) ⇒ Object
Sets the the path where the given class will load from. See using_yaml_path for information on how to override this on a per-instance basis.
59 60 61 |
# File 'lib/using_yaml.rb', line 59 def path=(args) (@@path ||= {})[args.first] = args.last end |